==> kubernetes-model-storageclass-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/storage/StorageClassListBuilder.java <==
package io.fabric8.kubernetes.api.model.storage;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class StorageClassListBuilder extends io.fabric8.kubernetes.api.model.storage.StorageClassListFluentImpl<io.fabric8.kubernetes.api.model.storage.StorageClassListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.storage.StorageClassList,io.fabric8.kubernetes.api.model.storage.StorageClassListBuilder>{
  public StorageClassListBuilder() {
    this(false);
  }
  public StorageClassListBuilder(java.lang.Boolean validationEnabled) {
    this(new StorageClassList(), validationEnabled);
  }
  public StorageClassListBuilder(io.fabric8.kubernetes.api.model.storage.StorageClassListFluent<?> fluent) {
    this(fluent, false);
  }
  public StorageClassListBuilder(io.fabric8.kubernetes.api.model.storage.StorageClassListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new StorageClassList(), validationEnabled);
  }
  public StorageClassListBuilder(io.fabric8.kubernetes.api.model.storage.StorageClassListFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.StorageClassList instance) {
    this(fluent, instance, false);
  }
  public StorageClassListBuilder(io.fabric8.kubernetes.api.model.storage.StorageClassListFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.StorageClassList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  public StorageClassListBuilder(io.fabric8.kubernetes.api.model.storage.StorageClassList instance) {
    this(instance,false);
  }
  public StorageClassListBuilder(io.fabric8.kubernetes.api.model.storage.StorageClassList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.storage.StorageClassListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.storage.StorageClassList build() {
    StorageClassList buildable = new StorageClassList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StorageClassListBuilder that = (StorageClassListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-storageclass-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/storage/StorageClassListBuilder.java <==
package io.fabric8.kubernetes.api.model.storage;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class StorageClassListBuilder extends io.fabric8.kubernetes.api.model.storage.StorageClassListFluentImpl<io.fabric8.kubernetes.api.model.storage.StorageClassListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.storage.StorageClassList,io.fabric8.kubernetes.api.model.storage.StorageClassListBuilder>{
  public StorageClassListBuilder() {
    this(false);
  }
  public StorageClassListBuilder(java.lang.Boolean validationEnabled) {
    this(new StorageClassList(), validationEnabled);
  }
  public StorageClassListBuilder(io.fabric8.kubernetes.api.model.storage.StorageClassListFluent<?> fluent) {
    this(fluent, false);
  }
  public StorageClassListBuilder(io.fabric8.kubernetes.api.model.storage.StorageClassListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new StorageClassList(), validationEnabled);
  }
  public StorageClassListBuilder(io.fabric8.kubernetes.api.model.storage.StorageClassListFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.StorageClassList instance) {
    this(fluent, instance, false);
  }
  public StorageClassListBuilder(io.fabric8.kubernetes.api.model.storage.StorageClassListFluent<?> fluent,io.fabric8.kubernetes.api.model.storage.StorageClassList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public StorageClassListBuilder(io.fabric8.kubernetes.api.model.storage.StorageClassList instance) {
    this(instance,false);
  }
  public StorageClassListBuilder(io.fabric8.kubernetes.api.model.storage.StorageClassList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.storage.StorageClassListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.storage.StorageClassList build() {
    StorageClassList buildable = new StorageClassList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StorageClassListBuilder that = (StorageClassListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
